import {setOptions} from "@/echarts/echarts";
import * as echarts from 'echarts';
export function setEcharts(ele,option){
    setOptions(ele,option)
}
export function setLabelStaTopEcharts(ele,tempdate,ywsl,sptzjtg,zjbtg_s,wzjs_s) {
    let  option = {
        backgroundColor: '#fff',
        color: ['#36639c', '#75a6e8', '#FF0000', '#12b5b0'],
        barWidth: 14,
        title: {
            text: '概览统计图',
            //subtext: '（数据统计范围：截止日期前14天）'
        },
        tooltip: {
            trigger: 'axis',
            axisPointer: {
                type: 'shadow'
            }
        },
        legend: {
            x: 'right', //可设定图例在左、右、居中
            icon: 'rect',
            left:'center',
            bottom:'10',
            textStyle: { //图例文字的样式
                color: '#8C8C8C',
                fontSize: 12
            },
            data: ['业务数量','市质检通过','市质检不通过','市未质检']
            //data: ['业务数量', '委平台质检通过','市信用质检通过','委平台质检不通过','市平台质检不通过','市平台未质检数']
        },
        grid: {
            left: '3%',
            right: '4%',
            bottom: '40',
            containLabel: true
        },
        xAxis: {
            type: 'category',
            splitLine: {
                show: false // 去除网格线
            },
            axisLine: {
                lineStyle: {
                    type: 'solid',
                    color: '#BFBFBF', // 坐标线的颜色
                    width: '1'
                }
            },
            axisLabel: {
                textStyle: {
                    color: '#595959' //坐标值的颜色
                },
                formatter: function (params) {
                    var newParamsName = ''
                    var paramsNameNumber = params.length //总字数
                    var provideNumber = 5 //一行显示几个字
                    var rowNumber = Math.ceil(paramsNameNumber / provideNumber)
                    if (paramsNameNumber > provideNumber) {
                        for (var p = 0; p < rowNumber; p++) {
                            var tempStr = ''
                            var start = p * provideNumber
                            var end = start + provideNumber
                            if (p == rowNumber - 1) {
                                tempStr = params.substring(start, paramsNameNumber)
                            } else {
                                tempStr = params.substring(start, end) + '\n'
                            }
                            newParamsName += tempStr
                        }
                    } else {
                        newParamsName = params
                    }
                    return newParamsName
                }
            },
            boundaryGap: [0, 0.01],
            data: tempdate
        },
        yAxis: {
            type: 'value',
            splitLine: {
                // show: false // 去除网格线
                lineStyle: {
                    color: '#E8E8E8',
                    type: 'dashed' //设置间隔线为虚线
                }
            },
            axisTick: {
                show: false //小横线
            },
            splitArea: {
                // show: true // 保留网格区域
            },
            axisLine: {
                show: false, // 去除纵向边框线
                lineStyle: {
                    type: 'solid',
                    color: '#BFBFBF', // 坐标线的颜色
                    width: '1'
                }
            },
            axisLabel: {
                textStyle: {
                    color: '#595959' //坐标值的颜色
                }
            }
        },
        series: [
            {
                name: '业务数量',
                type: 'bar',
                label: {
                    show: false,
                    position: 'right', // 位置
                    color: '#298DFF',
                    fontSize: 12,
                    fontWeight: 'normal', // 加粗
                    distance: 5, // 距离
                    offset: [0, 1] // 偏移距离[横向，纵向]
                }, // 柱子上方的数值
                data: ywsl
            },
            // {
            //     name: '委平台质检通过',
            //     type: 'bar',
            //     label: {
            //         show: false,
            //         position: 'right', // 位置
            //         color: '#33CA66',
            //         fontSize: 12,
            //         fontWeight: 'normal', // 加粗
            //         distance: 5, // 距离
            //         offset: [0, 2] // 偏移距离[横向，纵向]
            //     }, // 柱子右方的数值
            //     data: wptzjtg
            // },
            {
                name: '市质检通过',
                type: 'bar',
                label: {
                    show: false,
                    position: 'right', // 位置
                    color: '#33CA66',
                    fontSize: 12,
                    fontWeight: 'normal', // 加粗
                    distance: 5, // 距离
                    offset: [0, 2] // 偏移距离[横向，纵向]
                }, // 柱子右方的数值
                data: sptzjtg
            },
            // {
            //     name: '委平台质检不通过',
            //     type: 'bar',
            //     label: {
            //         show: false,
            //         position: 'right', // 位置
            //         color: '#33CA66',
            //         fontSize: 12,
            //         fontWeight: 'normal', // 加粗
            //         distance: 5, // 距离
            //         offset: [0, 2] // 偏移距离[横向，纵向]
            //     }, // 柱子右方的数值
            //     data: zjbtg_w
            // },
            {
                name: '市质检不通过',
                type: 'bar',
                label: {
                    show: false,
                    position: 'right', // 位置
                    color: '#33CA66',
                    fontSize: 12,
                    fontWeight: 'normal', // 加粗
                    distance: 5, // 距离
                    offset: [0, 2] // 偏移距离[横向，纵向]
                }, // 柱子右方的数值
                data: zjbtg_s
            }
            ,
            {
                name: '市未质检',
                type: 'bar',
                label: {
                    show: false,
                    position: 'right', // 位置
                    color: '#33CA66',
                    fontSize: 12,
                    fontWeight: 'normal', // 加粗
                    distance: 5, // 距离
                    offset: [0, 2] // 偏移距离[横向，纵向]
                }, // 柱子右方的数值
                data: wzjs_s
            }

        ]
    };
    setOptions(ele,option)
}

export function setLabelStaBottomEcharts(ele,map) {
    let  option = {
        title: {
            text: '数据延迟图',
            //subtext: '（数据统计范围：截止日期前14天）'
        },
        legend: [{
            show: true,
            data: ['归集委平台最大延迟'],
            textStyle: {
                fontFamily: 'Open Sans',
                color: '#33363b',
                fontSize: 13,
            },
            orient: 'horizontal',
            right: '34%',
            bottom: '1%',
            icon: "rect",
            padding: [5, 10]
            //itemWidth: 8,
            //itemHeight: 8,
        }, {
            show: true,
            data: ['归集委平台最小延迟'],
            textStyle: {
                fontFamily: 'Open Sans',
                color: '#33363b',
                fontSize: 13,
            },
            orient: 'horizontal',
            left: '34%',
            bottom: '1%',
            icon: "rect",
            padding: [5, 10]
            //itemWidth: 8,
            //itemHeight: 8,
        }],
        grid: {
            left: '3%',
            right: '4%',
            bottom: '40',
            containLabel: true
        },
        tooltip: {
            trigger: 'axis',
        },
        xAxis: {
            type: 'category',
            data: map["tempdate"],
            axisLine: {
                show: true,
                lineStyle: {
                    color: "#e8e8e8",
                    width: 1,
                    type: "dashed"
                },
            },
            axisLabel: {
                textStyle: {
                    fontFamily: 'Microsoft YaHei',
                    color: '#33363b', //X轴标注文字的颜色,
                    fontSize: 13, //X轴标注文字的大小
                },
            },
            axisTick: {
                show: false,
                alignWithLabel: true
            },
        },
        yAxis: {
            type: 'value',
            axisTick: {
                show: false,
            },
            axisLine: {
                show: false,
            },
            axisLabel: {
                textStyle: {
                    fontFamily: 'Open Sans',
                    color: '#868d9b', //X轴标注文字的颜色,
                    fontSize: 14, //X轴标注文字的大小
                },
            },
            splitLine: {
                show: true,
                lineStyle: {
                    color: "#e8e8e8",
                    width: 1,
                    type: "dashed",
                },
            },
        },
        series: [{
            name: '归集委平台最小延迟',
            type: 'line',
            smooth: true,
            symbol: 'circle',
            symbolSize: 8,
            itemStyle: {
                normal: {
                    color: '#1699c2',
                }
            },
            data: map["minYC"]
        },
            {
                name: '归集委平台最大延迟',
                type: 'line',
                smooth: true,
                symbol: 'circle',
                symbolSize: 8,
                itemStyle: {
                    normal: {
                        color: '#ecab3e',
                    }
                },
                data: map["maxYC"]
            },
        ]
    };
    setOptions(ele,option)
}

